@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -34,15 +32,15 @@
 
 static char *
 gdk_wayland_app_launch_context_get_startup_notify_id (GAppLaunchContext *context,
-						      GAppInfo          *info, 
-						      GList             *files)
+                                                      GAppInfo          *info,
+                                                      GList             *files)
 {
   return NULL;
 }
 
 static void
-gdk_wayland_app_launch_context_launch_failed (GAppLaunchContext *context, 
-					      const char        *startup_notify_id)
+gdk_wayland_app_launch_context_launch_failed (GAppLaunchContext *context,
+                                              const char        *startup_notify_id)
 {
 }
 
@@ -61,6 +59,8 @@ struct _GdkWaylandAppLaunchContextClass
   GdkAppLaunchContextClass base_class;
 };
 
+GType gdk_wayland_app_launch_context_get_type (void);
+
 G_DEFINE_TYPE (GdkWaylandAppLaunchContext, gdk_wayland_app_launch_context, GDK_TYPE_APP_LAUNCH_CONTEXT)
 
 static void
