@@ -26,6 +26,11 @@ struct _GdkWin32Display
 {
   GdkDisplay display;
 
+  Win32CursorTheme *cursor_theme;
+  gchar *cursor_theme_name;
+  int cursor_theme_size;
+  GHashTable *cursor_cache;
+
   /* WGL/OpenGL Items */
   guint have_wgl : 1;
   guint gl_version;
