@@ -52,6 +52,8 @@ enum {
 static guint cssnode_signals[LAST_SIGNAL] = { 0 };
 static GParamSpec *cssnode_properties[NUM_PROPERTIES];
 
+static GQuark quark_global_cache;
+
 static GtkStyleProviderPrivate *
 gtk_css_node_get_style_provider_or_null (GtkCssNode *cssnode)
 {
@@ -214,7 +216,7 @@ lookup_in_global_parent_cache (GtkCssNode                  *node,
       !may_use_global_parent_cache (node))
     return NULL;
 
-  cache = g_object_get_data (G_OBJECT (parent), "gtk-global-cache");
+  cache = g_object_get_qdata (G_OBJECT (parent), quark_global_cache);
   if (cache == NULL)
     return NULL;
 
@@ -289,14 +291,17 @@ store_in_global_parent_cache (GtkCssNode                  *node,
   if (!may_be_stored_in_parent_cache (style))
     return;
 
-  cache = g_object_get_data (G_OBJECT (parent), "gtk-global-cache");
+  cache = g_object_get_qdata (G_OBJECT (parent), quark_global_cache);
   if (cache == NULL)
     {
       cache = g_hash_table_new_full (gtk_global_parent_cache_hash,
                                      gtk_global_parent_cache_equal,
                                      gtk_global_parent_cache_free,
                                      g_object_unref);
-      g_object_set_data_full (G_OBJECT (parent), "gtk-global-cache", cache, (GDestroyNotify) g_hash_table_destroy);
+      g_object_set_qdata_full (G_OBJECT (parent),
+                               quark_global_cache,
+                               cache,
+                               (GDestroyNotify) g_hash_table_destroy);
     }
 
   g_hash_table_insert (cache,
@@ -389,7 +394,7 @@ gtk_css_node_real_update_style (GtkCssNode   *cssnode,
                                               gtk_css_node_get_style_provider (cssnode),
                                               should_create_transitions (change) ? style : NULL);
     }
-  else if (GTK_IS_CSS_ANIMATED_STYLE (style) && (change & GTK_CSS_CHANGE_TIMESTAMP))
+  else if (static_style != style && (change & GTK_CSS_CHANGE_TIMESTAMP))
     {
       new_style = gtk_css_animated_style_new_advance (GTK_CSS_ANIMATED_STYLE (style),
                                                       static_style,
@@ -522,6 +527,8 @@ gtk_css_node_class_init (GtkCssNodeClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+  quark_global_cache = g_quark_from_static_string ("gtk-global-cache");
+
   object_class->get_property = gtk_css_node_get_property;
   object_class->set_property = gtk_css_node_set_property;
   object_class->dispose = gtk_css_node_dispose;
@@ -1054,16 +1061,11 @@ gtk_css_node_get_junction_sides (GtkCssNode *cssnode)
 static void
 gtk_css_node_clear_classes (GtkCssNode *cssnode)
 {
-  GList *list, *l;
-  
-  list = gtk_css_node_declaration_list_classes (cssnode->decl);
-
-  for (l = list; l; l = l->next)
+  if (gtk_css_node_declaration_clear_classes (&cssnode->decl))
     {
-      gtk_css_node_remove_class (cssnode, GPOINTER_TO_UINT (l->data));
+      gtk_css_node_invalidate (cssnode, GTK_CSS_CHANGE_CLASS);
+      g_object_notify_by_pspec (G_OBJECT (cssnode), cssnode_properties[PROP_CLASSES]);
     }
-
-  g_list_free (list);
 }
 
 void
@@ -1090,22 +1092,20 @@ gtk_css_node_set_classes (GtkCssNode  *cssnode,
 char **
 gtk_css_node_get_classes (GtkCssNode *cssnode)
 {
-  GList *list, *l;
-  GPtrArray *result;
-  
-  list = gtk_css_node_declaration_list_classes (cssnode->decl);
-  result = g_ptr_array_new ();
+  const GQuark *classes;
+  char **result;
+  guint n_classes, i, j;
 
-  for (l = list; l; l = l->next)
+  classes = gtk_css_node_declaration_get_classes (cssnode->decl, &n_classes);
+  result = g_new (char *, n_classes + 1);
+
+  for (i = n_classes, j = 0; i-- > 0; ++j)
     {
-      g_ptr_array_add (result, g_strdup (g_quark_to_string (GPOINTER_TO_UINT (l->data))));
+      result[j] = g_strdup (g_quark_to_string (classes[i]));
     }
 
-  g_ptr_array_add (result, NULL);
-
-  g_list_free (list);
-
-  return (char **) g_ptr_array_free (result, FALSE);
+  result[n_classes] = NULL;
+  return result;
 }
 
 void
@@ -1137,10 +1137,11 @@ gtk_css_node_has_class (GtkCssNode *cssnode,
   return gtk_css_node_declaration_has_class (cssnode->decl, style_class);
 }
 
-GList *
-gtk_css_node_list_classes (GtkCssNode *cssnode)
+const GQuark *
+gtk_css_node_list_classes (GtkCssNode *cssnode,
+                           guint      *n_classes)
 {
-  return gtk_css_node_declaration_list_classes (cssnode->decl);
+  return gtk_css_node_declaration_get_classes (cssnode->decl, n_classes);
 }
 
 void
@@ -1265,8 +1266,10 @@ gtk_css_node_validate_internal (GtkCssNode *cssnode,
    * Note that this also completely revalidates child widgets all
    * the time.
    */
-  if (G_UNLIKELY (gtk_get_debug_flags () & GTK_DEBUG_NO_CSS_CACHE))
+#ifdef G_ENABLE_DEBUG
+  if (GTK_DEBUG_CHECK (NO_CSS_CACHE))
     cssnode->pending_changes |= GTK_CSS_CHANGE_ANY;
+#endif
 
   if (!cssnode->invalid)
     return;
