@@ -54,13 +54,10 @@ static GtkCssValue *
 gtk_css_value_shadows_compute (GtkCssValue             *value,
                                guint                    property_id,
                                GtkStyleProviderPrivate *provider,
-			       int                      scale,
-                               GtkCssStyle    *values,
-                               GtkCssStyle    *parent_values,
-                               GtkCssDependencies      *dependencies)
+                               GtkCssStyle             *style,
+                               GtkCssStyle             *parent_style)
 {
   GtkCssValue *result;
-  GtkCssDependencies child_deps;
   guint i;
 
   if (value->len == 0)
@@ -69,8 +66,7 @@ gtk_css_value_shadows_compute (GtkCssValue             *value,
   result = gtk_css_shadows_value_new (value->values, value->len);
   for (i = 0; i < value->len; i++)
     {
-      result->values[i] = _gtk_css_value_compute (value->values[i], property_id, provider, scale, values, parent_values, &child_deps);
-      *dependencies = _gtk_css_dependencies_union (*dependencies, child_deps);
+      result->values[i] = _gtk_css_value_compute (value->values[i], property_id, provider, style, parent_style);
     }
 
   return result;
