@@ -105,7 +105,7 @@
 #define TAIL_GAP_WIDTH  24
 #define TAIL_HEIGHT     12
 #define TRANSITION_DIFF 20
-#define TRANSITION_DURATION 330 * 1000
+#define TRANSITION_DURATION 150 * 1000
 
 #define POS_IS_VERTICAL(p) ((p) == GTK_POS_TOP || (p) == GTK_POS_BOTTOM)
 
@@ -153,7 +153,6 @@ struct _GtkPopoverPrivate
   guint current_position   : 2;
   guint modal              : 1;
   guint button_pressed     : 1;
-  guint apply_shape        : 1;
   guint grab_notify_blocked : 1;
   guint transitions_enabled : 1;
   guint state               : 2;
@@ -183,7 +182,6 @@ gtk_popover_init (GtkPopover *popover)
   gtk_widget_set_has_window (widget, TRUE);
   popover->priv = gtk_popover_get_instance_private (popover);
   popover->priv->modal = TRUE;
-  popover->priv->apply_shape = TRUE;
   popover->priv->tick_id = 0;
   popover->priv->transitions_enabled = TRUE;
 
@@ -517,7 +515,7 @@ show_animate_cb (GtkWidget     *widget,
       gtk_widget_set_opacity (widget, 1.0 - t);
     }
 
-  gtk_widget_queue_resize (GTK_WIDGET (popover));
+  gtk_popover_update_position (popover);
 
   if (t >= 1.0)
     {
@@ -616,22 +614,6 @@ gtk_popover_unmap (GtkWidget *widget)
   g_clear_object (&priv->prev_default);
 }
 
-static void
-gtk_popover_get_pointed_to_coords (GtkPopover   *popover,
-                                   GdkRectangle *rect_out)
-{
-  GtkPopoverPrivate *priv = popover->priv;
-  GdkRectangle rect;
-
-  if (!rect_out)
-    return;
-
-  gtk_popover_get_pointing_to (popover, &rect);
-  gtk_widget_translate_coordinates (priv->widget, GTK_WIDGET (priv->window),
-                                    rect.x, rect.y, &rect.x, &rect.y);
-  *rect_out = rect;
-}
-
 static GtkPositionType
 get_effective_position (GtkPopover      *popover,
                         GtkPositionType  pos)
@@ -972,7 +954,10 @@ gtk_popover_update_position (GtkPopover *popover)
   gtk_widget_get_allocation (GTK_WIDGET (priv->window), &window_alloc);
   priv->final_position = priv->preferred_position;
 
-  gtk_popover_get_pointed_to_coords (popover, &rect);
+  gtk_popover_get_pointing_to (popover, &rect);
+  gtk_widget_translate_coordinates (priv->widget, GTK_WIDGET (priv->window),
+                                    rect.x, rect.y, &rect.x, &rect.y);
+
   pos = get_effective_position (popover, priv->preferred_position);
 
   overshoot[GTK_POS_TOP] = req.height - rect.y;
@@ -1032,7 +1017,7 @@ gtk_popover_update_position (GtkPopover *popover)
 
   if (priv->final_position != priv->current_position)
     {
-      if (priv->apply_shape && gtk_widget_is_drawable (widget))
+      if (gtk_widget_is_drawable (widget))
         gtk_popover_update_shape (popover);
 
       priv->current_position = priv->final_position;
@@ -1348,7 +1333,6 @@ gtk_popover_size_allocate (GtkWidget     *widget,
                            GtkAllocation *allocation)
 {
   GtkPopover *popover = GTK_POPOVER (widget);
-  GtkPopoverPrivate *priv = popover->priv;
   GtkWidget *child;
 
   gtk_widget_set_allocation (widget, allocation);
@@ -1373,8 +1357,7 @@ gtk_popover_size_allocate (GtkWidget     *widget,
     {
       gdk_window_move_resize (gtk_widget_get_window (widget),
                               0, 0, allocation->width, allocation->height);
-      if (priv->apply_shape)
-        gtk_popover_update_shape (popover);
+      gtk_popover_update_shape (popover);
     }
 }
 
