@@ -59,8 +59,8 @@ struct _GtkRangeClass
   GtkWidgetClass parent_class;
 
   /* what detail to pass to GTK drawing functions */
-  gchar *slider_detail;
-  gchar *stepper_detail;
+  G_GNUC_DEPRECATED gchar *slider_detail;
+  G_GNUC_DEPRECATED gchar *stepper_detail;
 
   void (* value_changed)    (GtkRange     *range);
   void (* adjust_bounds)    (GtkRange     *range,
@@ -86,80 +86,93 @@ struct _GtkRangeClass
 };
 
 
+GDK_AVAILABLE_IN_ALL
 GType              gtk_range_get_type                      (void) G_GNUC_CONST;
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_adjustment                (GtkRange      *range,
                                                             GtkAdjustment *adjustment);
+GDK_AVAILABLE_IN_ALL
 GtkAdjustment*     gtk_range_get_adjustment                (GtkRange      *range);
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_inverted                  (GtkRange      *range,
                                                             gboolean       setting);
+GDK_AVAILABLE_IN_ALL
 gboolean           gtk_range_get_inverted                  (GtkRange      *range);
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_flippable                 (GtkRange      *range,
                                                             gboolean       flippable);
+GDK_AVAILABLE_IN_ALL
 gboolean           gtk_range_get_flippable                 (GtkRange      *range);
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_slider_size_fixed         (GtkRange      *range,
                                                             gboolean       size_fixed);
+GDK_AVAILABLE_IN_ALL
 gboolean           gtk_range_get_slider_size_fixed         (GtkRange      *range);
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_min_slider_size           (GtkRange      *range,
                                                             gint           min_size);
+GDK_AVAILABLE_IN_ALL
 gint               gtk_range_get_min_slider_size           (GtkRange      *range);
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_get_range_rect                (GtkRange      *range,
                                                             GdkRectangle  *range_rect);
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_get_slider_range              (GtkRange      *range,
                                                             gint          *slider_start,
                                                             gint          *slider_end);
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_lower_stepper_sensitivity (GtkRange      *range,
                                                             GtkSensitivityType sensitivity);
+GDK_AVAILABLE_IN_ALL
 GtkSensitivityType gtk_range_get_lower_stepper_sensitivity (GtkRange      *range);
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_upper_stepper_sensitivity (GtkRange      *range,
                                                             GtkSensitivityType sensitivity);
+GDK_AVAILABLE_IN_ALL
 GtkSensitivityType gtk_range_get_upper_stepper_sensitivity (GtkRange      *range);
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_increments                (GtkRange      *range,
                                                             gdouble        step,
                                                             gdouble        page);
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_range                     (GtkRange      *range,
                                                             gdouble        min,
                                                             gdouble        max);
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_value                     (GtkRange      *range,
                                                             gdouble        value);
+GDK_AVAILABLE_IN_ALL
 gdouble            gtk_range_get_value                     (GtkRange      *range);
 
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_show_fill_level           (GtkRange      *range,
                                                             gboolean       show_fill_level);
+GDK_AVAILABLE_IN_ALL
 gboolean           gtk_range_get_show_fill_level           (GtkRange      *range);
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_restrict_to_fill_level    (GtkRange      *range,
                                                             gboolean       restrict_to_fill_level);
+GDK_AVAILABLE_IN_ALL
 gboolean           gtk_range_get_restrict_to_fill_level    (GtkRange      *range);
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_fill_level                (GtkRange      *range,
                                                             gdouble        fill_level);
+GDK_AVAILABLE_IN_ALL
 gdouble            gtk_range_get_fill_level                (GtkRange      *range);
+GDK_AVAILABLE_IN_ALL
 void               gtk_range_set_round_digits              (GtkRange      *range,
                                                             gint           round_digits);
+GDK_AVAILABLE_IN_ALL
 gint                gtk_range_get_round_digits              (GtkRange      *range);
 
-/* internal API */
-gdouble            _gtk_range_get_wheel_delta              (GtkRange       *range,
-                                                            GdkEventScroll *event);
-void               _gtk_range_set_has_origin               (GtkRange      *range,
-                                                            gboolean       has_origin);
-gboolean           _gtk_range_get_has_origin               (GtkRange      *range);
-void               _gtk_range_set_stop_values              (GtkRange      *range,
-                                                            gdouble       *values,
-                                                            gint           n_values);
-gint               _gtk_range_get_stop_positions           (GtkRange      *range,
-                                                            gint         **values);
-void               _gtk_range_set_steppers                 (GtkRange      *range,
-                                                            gboolean       has_a,
-                                                            gboolean       has_b,
-                                                            gboolean       has_c,
-                                                            gboolean       has_d);
 
 G_END_DECLS
 
